<?php
function it_exchange_exporter_file_encoding( $content = '' ) {

	global $export;

	if( function_exists( 'mb_convert_encoding' ) ) {
		$to_encoding = $export->encoding;
		// $from_encoding = 'auto';
		$from_encoding = 'ISO-8859-1';
		if( !empty( $to_encoding ) )
			$content = mb_convert_encoding( trim( $content ), $to_encoding, $from_encoding );
		if( $to_encoding == 'UTF-8' )
			$content = utf8_decode( $content );
	}
	return $content;

}

function it_exchange_exporter_display_memory( $memory = 0 ) {

	$output = '-';
	if( !empty( $output ) )
		$output = sprintf( __( '%s MB', 'woo_ce' ), $memory );
	echo $output;

}

function it_exchange_exporter_display_time_elapsed( $from, $to ) {

	$output = __( '1 second', 'exchange-addon-exporter' );
	$time = $to - $from;
	$tokens = array (
		31536000 => __( 'year', 'exchange-addon-exporter' ),
		2592000 => __( 'month', 'exchange-addon-exporter' ),
		604800 => __( 'week', 'exchange-addon-exporter' ),
		86400 => __( 'day', 'exchange-addon-exporter' ),
		3600 => __( 'hour', 'exchange-addon-exporter' ),
		60 => __( 'minute', 'exchange-addon-exporter' ),
		1 => __( 'second', 'exchange-addon-exporter' )
	);
	foreach ($tokens as $unit => $text) {
		if ($time < $unit) continue;
		$numberOfUnits = floor($time / $unit);
		$output = $numberOfUnits . ' ' . $text . ( ( $numberOfUnits > 1 ) ? 's' : '' );
	}
	return $output;

}

// @mod - Compare to WP e-Commerce for field escaping, remove if not required
// This function escapes all cells in 'Excel' CSV escape formatting of a CSV file, also converts HTML entities to plain-text
function it_exchange_exporter_escape_csv_value( $string = '', $delimiter = ',', $format = 'all' ) {

	$string = str_replace( '"', '""', $string );
	$string = wp_specialchars_decode( $string );
	$string = preg_replace('/&([^#])(?![a-z1-4]{1,8};)/i', '&#038;$1', $string );
	$string = str_replace( PHP_EOL, "\r\n", $string );
	switch( $format ) {

		case 'all':
			$string = '"' . $string . '"';
			break;

		case 'excel':
			if( strpos( $string, '"' ) !== false or strpos( $string, ',' ) !== false or strpos( $string, "\r" ) !== false or strpos( $string, "\n" ) !== false )
				$string = '"' . $string . '"';
			break;

	}
	return $string;

}

function it_exchange_exporter_format_visibility( $visibility = '' ) {

	$output = '';
	if( $visibility ) {
		switch( $visibility ) {

			case 'visible':
				$output = __( 'Show in Store', 'exchange-addon-exporter' );
				break;

			case 'hidden':
				$output = __( 'Hide from Store', 'exchange-addon-exporter' );
				break;

		}
	}
	return $output;

}

function it_exchange_exporter_format_product_status( $product_status = '' ) {

	$output = $product_status;
	switch( $product_status ) {

		case 'publish':
			$output = __( 'Publish', 'exchange-addon-exporter' );
			break;

		case 'pending':
			$output = __( 'Pending Review', 'exchange-addon-exporter' );
			break;

		case 'draft':
			$output = __( 'Draft', 'exchange-addon-exporter' );
			break;

		case 'trash':
			$output = __( 'Trash', 'exchange-addon-exporter' );
			break;

	}
	return $output;

}

function it_exchange_exporter_format_availability( $type_id = '', $availability = array() ) {

	$output = '';
	if( !empty( $type_id ) ) {
		if( isset( $availability[$type_id] ) )
			$output = it_exchange_exporter_format_date( 'd/m/Y', $availability[$type_id] );
	}
	return $output;

}

function it_exchange_exporter_format_date( $date_format = 'd/m/Y', $timestamp = 0 ) {

	$output = $timestamp;
	if( !empty( $output ) ) {
		$output = date( $date_format, $timestamp );
	}
	return $output;

}

function it_exchange_exporter_format_switch( $input = '', $output_format = 'answer' ) {

	$input = strtolower( $input );
	switch( $input ) {

		case '1':
		case 'yes':
		case 'on':
		case 'open':
		case 'active':
			$input = '1';
			break;

		case '0':
		case 'no':
		case 'off':
		case 'closed':
		case 'inactive':
		default:
			$input = '0';
			break;

	}
	$output = '';
	switch( $output_format ) {

		case 'int':
			$output = $input;
			break;

		case 'answer':
			switch( $input ) {

				case '1':
					$output = __( 'Yes', 'exchange-addon-exporter' );
					break;

				case '0':
					$output = __( 'No', 'exchange-addon-exporter' );
					break;

			}
			break;

		case 'boolean':
			switch( $input ) {

				case '1':
					$output = 'on';
					break;

				case '0':
					$output = 'off';
					break;

			}
			break;

	}
	return $output;

}
function it_exchange_exporter_format_product_type( $type_id = '' ) {

	$output = $type_id;
	if( !empty( $output ) ) {
		$product_types = apply_filters( 'it_exchange_exporter_format_product_types', array(
			'simple-product-type' => __( 'Simple Product', 'exchange-addon-exporter' ),
			'physical-product-type' => __( 'Physical Product', 'exchange-addon-exporter' ),
			'digital-downloads-product-type'  => __( 'Digital Download', 'exchange-addon-exporter' )
		) );
		if( isset( $product_types[$type_id] ) )
			$output = $product_types[$type_id];
	}
	return $output;

}
?>