<?php
// Returns a list of iThemes Exchange Product IDs to export process
function it_exchange_exporter_get_products( $args = array() ) {

	$limit_volume = -1;
	$offset = 0;
	if( $args ) {
		$limit_volume = $args['limit_volume'];
		$offset = $args['offset'];
	}
	$post_type = array( 'it_exchange_prod' );
	$args = array(
		'post_type' => $post_type,
		'offset' => $offset,
		'posts_per_page' => $limit_volume,
		'no_found_rows' => false,
		'fields' => 'ids'
	);
	$products = array();
	$product_ids = new WP_Query( $args );
	if( $product_ids->posts ) {
		foreach( $product_ids->posts as $product_id ) {
			$products[] = $product_id;
		}
		unset( $product_ids, $product_id );
	}
	return $products;

}

function it_exchange_exporter_get_product_data( $product_id = 0, $args = array() ) {

	// Get Product defaults

	$product = get_post( $product_id );
	$product->product_id = $product->ID;
	$product->parent_id = $product->post_parent;
	$product->product_title = $product->post_title;
	$product->description = $product->post_content;
	$product->extended_description = get_post_meta( $product_id, '_it-exchange-product-description', true );
	$product->product_type = it_exchange_exporter_format_product_type( get_post_meta( $product_id, '_it-exchange-product-type', true ) );
	$product->price = ( get_post_meta( $product_id, '_it-exchange-base-price', true ) == '' ) ? '' : it_exchange_format_price( it_exchange_convert_from_database_number( get_post_meta( $product_id, '_it-exchange-base-price', true ) ) );
	$product->category = it_exchange_exporter_get_product_assoc_categories( $product_id, $product->parent_id );
	$product->featured_image = it_exchange_exporter_get_product_assoc_featured_image( $product_id );
	$product->image = it_exchange_exporter_get_product_assoc_images( $product_id );
	$product->inventory = ( get_post_meta( $product_id, '_it-exchange-product-enable-inventory', true ) == 'yes' ? get_post_meta( $product_id, '_it-exchange-product-inventory', true ) : '' );
	$product->purchase_quantity = ( get_post_meta( $product_id, '_it-exchange-product-allow-quantity', true ) == 'no' ? '' : get_post_meta( $product_id, '_it-exchange-product-quantity', true ) );
	$product->purchase_message = get_post_meta( $product_id, '_it-exchange-product-purchase-message', true );
	$product->product_status = it_exchange_exporter_format_product_status( $product->post_status );
	$product->visibility = it_exchange_exporter_format_visibility( get_post_meta( $product_id, '_it-exchange-visibility', true ) );
	$availability = get_post_meta( $product_id, '_it-exchange-product-availability', true );
	$product->availability_start = ( ( get_post_meta( $product_id, '_it-exchange-enable-product-availability-start', true ) == 'no' ) ? '' : it_exchange_exporter_format_availability( 'start', $availability ) );
	$product->availability_end = ( ( get_post_meta( $product_id, '_it-exchange-enable-product-availability-end', true ) == 'no' ) ? '' : it_exchange_exporter_format_availability( 'end', $availability ) );
	$product->disable_shipping = ( ( get_post_meta( $product_id, '_it-exchange-shipping-enabled', true ) == 1 ) ? '' : 'yes' );
	$product->store_order = $product->menu_order;
	$product->slug = $product->post_name;
	$product->page_template = get_post_meta( $product_id, '_wp_page_template', true );

	// Allow Plugin/Theme authors to add support for additional Product columns
	return apply_filters( 'it_exchange_exporter_product_item', $product, $product->ID );

}

// Returns Product Categories associated to a specific Product
function it_exchange_exporter_get_product_assoc_categories( $product_id = 0, $parent_id = 0 ) {

	global $export;

	$output = '';
	$term_taxonomy = 'it_exchange_category';
	// Return Product Categories of Parent if this is a Variation
	if( $parent_id )
		$product_id = $parent_id;
	if( $product_id )
		$categories = wp_get_object_terms( $product_id, $term_taxonomy );
	if( is_wp_error( $categories ) == false ) {
		$size = count( $categories );
		for( $i = 0; $i < $size; $i++ ) {
			if( $categories[$i]->parent == '0' ) {
				$output .= $categories[$i]->name . $export->category_separator;
			} else {
				// Check if Parent -> Child
				$parent_category = get_term( $categories[$i]->parent, $term_taxonomy );
				// Check if Parent -> Child -> Subchild
				if( $parent_category->parent == '0' ) {
					$output .= $parent_category->name . '>' . $categories[$i]->name . $export->category_separator;
					$output = str_replace( $parent_category->name . $export->category_separator, '', $output );
				} else {
					$root_category = get_term( $parent_category->parent, $term_taxonomy );
					$output .= $root_category->name . '>' . $parent_category->name . '>' . $categories[$i]->name . $export->category_separator;
					$output = str_replace( array(
						$root_category->name . '>' . $parent_category->name . $export->category_separator,
						$parent_category->name . $export->category_separator
					), '', $output );
				}
				unset( $root_category, $parent_category );
			}
		}
		$output = substr( $output, 0, -1 );
	} else {
		$output .= __( 'Uncategorized', 'exchange-addon-exporter' );
	}
	return $output;

}

function it_exchange_exporter_get_product_assoc_featured_image( $product_id = 0 ) {

	$output = '';
	if( $images = get_post_meta( $product_id, '_it-exchange-product-images', true ) ) {
		if( isset( $images[0] ) )
			$output = $images[0];
	}
	if( !empty( $output ) )
		$output = wp_get_attachment_url( $output );
	return $output;

}
function it_exchange_exporter_get_product_assoc_images( $product_id = 0 ) {

	global $export;

	$output = '';
	if( $images = get_post_meta( $product_id, '_it-exchange-product-images', true ) ) {
		$size = count( $images );
		for( $i = 0; $i < $size; $i++ ) {
			if( isset( $images[$i] ) )
				$images[$i] = wp_get_attachment_url( $images[$i] );
		}
		$output = implode( $export->category_separator, $images );
	}
	return $output;

}

// Returns a list of Product export columns
function it_exchange_exporter_get_product_fields( $format = 'full' ) {

	$fields = array();
	$fields[] = array(
		'name' => 'product_id',
		'label' => __( 'Product ID', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'product_title',
		'label' => __( 'Product Title', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'description',
		'label' => __( 'Description', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'extended_description',
		'label' => __( 'Extended Description', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'product_type',
		'label' => __( 'Product Type', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'price',
		'label' => __( 'Price', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'category',
		'label' => __( 'Category', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'featured_image',
		'label' => __( 'Featured Image', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'image',
		'label' => __( 'Images', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'inventory',
		'label' => __( 'Inventory', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'purchase_quantity',
		'label' => __( 'Purchase Quantity', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'purchase_message',
		'label' => __( 'Purchase Message', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'product_status',
		'label' => __( 'Product Status', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'visibility',
		'label' => __( 'Visibility', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'availability_start',
		'label' => __( 'Availability Start Date', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'availability_end',
		'label' => __( 'Availability End Date', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'disable_shipping',
		'label' => __( 'Disable Shipping', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'store_order',
		'label' => __( 'Store Order', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'slug',
		'label' => __( 'Slug', 'exchange-addon-exporter' )
	);
	$fields[] = array(
		'name' => 'page_template',
		'label' => __( 'Page Template', 'exchange-addon-exporter' )
	);

	if( $remember = it_exchange_exporter_get_option( 'products_fields' ) ) {
		$remember = maybe_unserialize( $remember );
		$size = count( $fields );
		for( $i = 0; $i < $size; $i++ ) {
			if( !array_key_exists( $fields[$i]['name'], $remember ) )
				$fields[$i]['default'] = 0;
		}
	}

	switch( $format ) {

		case 'summary':
			$output = array();
			$size = count( $fields );
			for( $i = 0; $i < $size; $i++ )
				$output[$fields[$i]['name']] = 'on';
			return $output;
			break;

		case 'full':
		default:
			return $fields;
			break;

	}

}

// Returns the export column header label based on an export column slug
function it_exchange_exporter_get_product_field( $name = null, $format = 'name' ) {

	$output = '';
	if( $name ) {
		$fields = it_exchange_exporter_get_product_fields();
		$size = count( $fields );
		for( $i = 0; $i < $size; $i++ ) {
			if( $fields[$i]['name'] == $name ) {
				switch( $format ) {

					case 'name':
						$output = $fields[$i]['label'];
						break;

					case 'full':
						$output = $fields[$i];
						break;

				}
				$i = $size;
			}
		}
	}
	return $output;

}
?>