<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

define( 'ITE_CE_DIRNAME', basename( dirname( __FILE__ ) ) );
define( 'ITE_CE_RELPATH', basename( dirname( __FILE__ ) ) . '/' . basename( __FILE__ ) );
define( 'ITE_CE_PATH', plugin_dir_path( __FILE__ ) );
define( 'ITE_CE_PREFIX', 'it_exchange_exporter' );

// Turn this on to enable additional debugging options at export time
define( 'ITE_CE_DEBUG', false );

include_once( ITE_CE_PATH . 'includes/common.php' );
include_once( ITE_CE_PATH . 'includes/functions.php' );

if( is_admin() ) {

	/* Start of: WordPress Administration */

	// Load CSS and jQuery scripts for Store Exporter screen
	function it_exchange_exporter_enqueue_scripts( $hook ) {

		$page = 'exchange_page_it-exchange-exporter';
		if( $page == $hook ) {
			// Common
			wp_enqueue_style( 'it_exchange_exporter_styles', plugins_url( '/templates/admin/it_exchange-admin_ce-export.css', __FILE__ ) );
			wp_enqueue_script( 'it_exchange_exporter_scripts', plugins_url( '/templates/admin/it_exchange-admin_ce-export.js', __FILE__ ), array( 'jquery' ) );
		}

	}
	add_action( 'admin_enqueue_scripts', 'it_exchange_exporter_enqueue_scripts' );

	// Initial scripts and export process
	function it_exchange_exporter_admin_init() {

		global $export;

		$action = it_exchange_get_action();
		switch( $action ) {

			// This is where the magic happens
			case 'export':

				// Set up the basic export options
				$export = new stdClass();
				$export->start_time = time();
				$export->idle_memory_start = it_exchange_exporter_current_memory_usage();
				$export->delete_csv = it_exchange_exporter_get_option( 'delete_csv', 0 );
				$export->encoding = it_exchange_exporter_get_option( 'encoding', get_option( 'blog_charset' ) );
				$export->delimiter = it_exchange_exporter_get_option( 'delimiter', ',' );
				$export->category_separator = it_exchange_exporter_get_option( 'category_separator', '|' );
				$export->bom = it_exchange_exporter_get_option( 'bom', 1 );
				$export->escape_formatting = it_exchange_exporter_get_option( 'escape_formatting', 'all' );

				// Save export option changes made on the Export screen
				$export->limit_volume = ( isset( $_POST['limit_volume'] ) ? $_POST['limit_volume'] : '' );
				it_exchange_exporter_update_option( 'limit_volume', $export->limit_volume );
				if( $export->limit_volume == '' )
					$export->limit_volume = -1;
				$export->offset = ( isset( $_POST['offset'] ) ? $_POST['offset'] : '' );
				it_exchange_exporter_update_option( 'offset', $export->offset );
				if( $export->offset == '' )
					$export->offset = 0;

				// Set default values for all export options to be later passed onto the export process
				$export->fields = false;
				$export->export_format = it_exchange_exporter_get_option( 'export_format', 'csv' );

				// Product sorting

				$export->type = ( isset( $_POST['dataset'] ) ? $_POST['dataset'] : false );
				switch( $export->type ) {

					case 'products':
						// Set up dataset specific options
						$export->fields = ( isset( $_POST['product_fields'] ) ? $_POST['product_fields'] : false );

						// Save dataset export specific options
						break;

				}
				if( $export->type ) {

					$timeout = 600;
					if( isset( $_POST['timeout'] ) ) {
						$timeout = (int)$_POST['timeout'];
						if( $timeout <> it_exchange_exporter_get_option( 'timeout' ) )
							it_exchange_exporter_update_option( 'timeout', $timeout );
					}
					if( !ini_get( 'safe_mode' ) )
						@set_time_limit( $timeout );

					@ini_set( 'memory_limit', WP_MAX_MEMORY_LIMIT );
					@ini_set( 'max_execution_time', (int)$timeout );

					$export->args = array(
						'limit_volume' => $export->limit_volume,
						'offset' => $export->offset,
						'encoding' => $export->encoding,
					);
					it_exchange_exporter_save_fields( $export->type, $export->fields );
					if( $export->export_format == 'csv' )
						$export->filename = it_exchange_exporter_generate_csv_filename( $export->type );
					// Print file contents to debug export screen
					if( ITE_CE_DEBUG ) {

						it_exchange_exporter_export_dataset( $export->type );
						$export->idle_memory_end = it_exchange_exporter_current_memory_usage();
						$export->end_time = time();

					// Print file contents to browser
					} else {
						if( $export->export_format == 'csv' ) {

							// Generate CSV contents
							$bits = it_exchange_exporter_export_dataset( $export->type );
							unset( $export->fields );
							if( !$bits ) {
								wp_redirect( add_query_arg( 'empty', true ) );
								exit();
							}
							if( $export->delete_csv ) {

								// Print to browser
								it_exchange_exporter_generate_csv_header( $export->type );
								echo $bits;
								exit();

							} else {

								// Save to file and insert to WordPress Media
								if( $export->filename && $bits ) {
									$post_ID = it_exchange_exporter_save_file_attachment( $export->filename, 'text/csv' );
									$upload = wp_upload_bits( $export->filename, null, $bits );
									if( $upload['error'] ) {
										wp_delete_attachment( $post_ID, true );
										wp_redirect( add_query_arg( array( 'failed' => true, 'message' => urlencode( $upload['error'] ) ) ) );
										return;
									}
									$attach_data = wp_generate_attachment_metadata( $post_ID, $upload['file'] );
									wp_update_attachment_metadata( $post_ID, $attach_data );
									update_attached_file( $post_ID, $upload['file'] );
									if( $post_ID ) {
										it_exchange_exporter_save_file_guid( $post_ID, $export->type, $upload['url'] );
										it_exchange_exporter_save_file_details( $post_ID );
									}
									$export_type = $export->type;
									unset( $export );

									// The end memory usage and time is collected at the very last opportunity prior to the CSV header being rendered to the screen
									it_exchange_exporter_update_file_detail( $post_ID, '_woo_idle_memory_end', it_exchange_exporter_current_memory_usage() );
									it_exchange_exporter_update_file_detail( $post_ID, '_woo_end_time', time() );

									// Generate CSV header
									it_exchange_exporter_generate_csv_header( $export_type );
									unset( $export_type );

									// Print file contents to screen
									if( $upload['file'] )
										readfile( $upload['file'] );
									else
										wp_redirect( add_query_arg( 'failed', true ) );
									unset( $upload );
								} else {
									wp_redirect( add_query_arg( 'failed', true ) );
								}
								exit();

							}

						}
					}
				}
				break;

			// Save changes on Settings screen
			case 'updated':
				$options = array(
					'filename' => ( isset( $_POST['filename'] ) ? (string)$_POST['filename'] : '' ),
					'delete_csv' => ( isset( $_POST['delete_csv'] ) ? (int)$_POST['delete_csv'] : '' ),
					'encoding' => ( isset( $_POST['encoding'] ) ? (string)$_POST['encoding'] : '' ),
					'timeout' => ( isset( $_POST['timeout'] ) ? (int)$_POST['timeout'] : 0 ),
					'delimiter' => ( isset( $_POST['delimiter'] ) ? (string)$_POST['delimiter'] : ',' ),
					'category_separator' => ( isset( $_POST['category_separator'] ) ? (string)$_POST['category_separator'] : '|' ),
					'bom' => ( isset( $_POST['bom'] ) ? (int)$_POST['bom'] : '' ),
					'escape_formatting' => ( isset( $_POST['escape_formatting'] ) ? (string)$_POST['escape_formatting'] : 'all' )
				);
				it_exchange_save_option( 'addon_exporter', $options );
				$message = __( 'Changes have been saved.', 'exchange-addon-exporter' );
				it_exchange_exporter_admin_notice( $message );
				break;

			default:
				// Detect other platform versions
				it_exchange_exporter_detect_non_exchange_install();

				add_action( 'it_exchange_exporter_export_options', 'it_exchange_exporter_export_options_export_format' );
				break;

		}

	}
	add_action( 'admin_init', 'it_exchange_exporter_admin_init' );

	// HTML templates and form processor for Store Exporter screen
	function it_exchange_exporter_html_page() {

		global $export;

		$title = __( 'Store Exporter', 'exchange-addon-exporter' );
		$title = apply_filters( 'it_exchange_exporter_template_header', $title );
		it_exchange_exporter_template_header( $title );
		it_exchange_exporter_support_donate();
		$action = it_exchange_get_action();
		switch( $action ) {

			case 'export':
				$message = __( 'Chosen iThemes Exchange details have been exported from your store.', 'exchange-addon-exporter' );
				it_exchange_exporter_admin_notice( $message );
				$output = '';
				if( ITE_CE_DEBUG ) {
					if( false === ( $export_log = get_transient( ITE_CE_PREFIX . '_debug_log' ) ) ) {
						$export_log = __( 'No export entries were found, please try again with different export filters.', 'exchange-addon-exporter' );
					} else {
						delete_transient( ITE_CE_PREFIX . '_debug_log' );
						$export_log = base64_decode( $export_log );
					}
					$output = '
<h3>' . __( 'Export Details', 'exchange-addon-exporter' ) . '</h3>
<textarea id="export_log">' . print_r( $export, true ) . '</textarea><hr />
<h3>' . sprintf( __( 'Export Log: %s', 'exchange-addon-exporter' ), $export->filename ) . '</h3>
<textarea id="export_log">' . $export_log . '</textarea>
';
				}
				echo $output;

				it_exchange_exporter_manage_form();
				break;

			default:
				it_exchange_exporter_manage_form();
				break;

		}
		it_exchange_exporter_template_footer();

	}

	// HTML template for Export screen
	function it_exchange_exporter_manage_form() {

		$tab = false;
		if( isset( $_GET['tab'] ) )
			$tab = $_GET['tab'];
		$url = add_query_arg( 'page', 'it-exchange-exporter' );

		include_once( ITE_CE_PATH . 'templates/admin/it_exchange-admin_ce-export.php' );

	}

	/* End of: WordPress Administration */

}
?>